package com.yeejoin.amos.server.gateway.config;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.gateway.filter.GatewayFilter;
import org.springframework.cloud.gateway.filter.factory.StripPrefixGatewayFilterFactory;
import org.springframework.cloud.gateway.route.RouteLocator;
import org.springframework.cloud.gateway.route.builder.RouteLocatorBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class GatewayInfo {

    static StripPrefixGatewayFilterFactory stripPrefixGatewayFilterFactory = new StripPrefixGatewayFilterFactory();

    static GatewayFilter gatewayFilter;

    static {
        StripPrefixGatewayFilterFactory.Config config = new StripPrefixGatewayFilterFactory.Config();
        config.setParts(1);
        gatewayFilter = stripPrefixGatewayFilterFactory.apply(config);
    }

    @Value("${iot.name}")
    private String IOT_ERUKA_NAME;

    @Value("${patrol.name}")
    private String PATROL_ERUKA_NAME;

    @Value("${bank.name}")
    private String BANK_ERUKA_NAME;

    @Value("${risk.name}")
    private String RISK_ERUKA_NAME;

    @Value("${duty.name}")
    private String DUTY_ERUKA_NAME;

//	private static final String IOT_ERUKA_NAME = "AMOSIOT-237";
//	private static final String PATROL_ERUKA_NAME = "YEEAMOSPATROL-237";
//	private static final String BANK_ERUKA_NAME = "AMOSBANK-XIANA237";

    /**
     * 跳转oauth服务
     *
     * @param builder
     * @return
     */
    @Bean
    public RouteLocator myRoutes(RouteLocatorBuilder builder) {
        return builder.routes().route(p -> p.path("/privilege/**").uri("lb://AMOS-API-PRIVILEGE"))
                .route(p -> p.path("/systemctl/**").uri("lb://AMOS-API-SYSTEMCTL"))
                .route(p -> p.path("/urule/**").uri("lb://AMOS-API-RULE"))

                // 注：前缀确定不重复得可以用/** 重复得用精确匹配， 完全重复得修改一个

                // 银行业务
                .route(p -> p.path("/bank/alarm/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/dynamicRingData/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/equipment/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/inspection/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/duty/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/phonebook/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/topography/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/warn/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/bank/test").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/alarm/alarmPage").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/alarm/mobile/getcountxd").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/message/page").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/message/mobile/getcountxd").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/excel/export").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/protal/data").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/protal/hiddentrouble").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/protal/riskFactor").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/rule/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcAftermath/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcCamera/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcControlMeasure/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcEuipmentFacilities/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcMajorHazardInstallation/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcMeasureContent/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/region/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcRiskFactor/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/riskList/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcRiskSource/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcSecurity/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/statistics/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/spcTaskwork/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/api/timeline/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/view3d/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/video/**").uri("lb://" + BANK_ERUKA_NAME))
                .route(p -> p.path("/rtsp/**").uri("lb://" + BANK_ERUKA_NAME))

                // 巡检业务
                .route(p -> p.path("/api/catalogTree/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/check/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/config/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/excel/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/group/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/home/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/inputItem/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/latent/danger/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/msgSubscribe/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/patrol/addRoute").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/plan/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/planTask/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/point/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/stats/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/riskJudgment/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/route/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/safe/save/curCompany").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/spc/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/syn/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/task/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/task/report/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/taskwork/**").uri("lb://" + PATROL_ERUKA_NAME))
                .route(p -> p.path("/api/user/**").uri("lb://" + PATROL_ERUKA_NAME))


                // IOT
                .route(p -> p.path("/alarm/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/company/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/device/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/metricdata/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/iot/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/history/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/intfc/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/protocol/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/reportdata/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/ruledeploy/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/rulemanage/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/section/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/dic/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/topo/**").uri("lb://" + IOT_ERUKA_NAME))
                .route(p -> p.path("/images/**").uri("lb://" + IOT_ERUKA_NAME))
              

                //风险
                .route(p -> p.path("/api/spcIdentificationMethod/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/spcEvaluateModel/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/spcRiskLevel/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/spcEvaluateNorm/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/spcHazardSourceClassify/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/riskLevel/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/risksource/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/riskModel/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/riskFactor/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/impEquip/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/common/deptment/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/common/pointList/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/common/pointInputlist/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/common/user/**").uri("lb://" + RISK_ERUKA_NAME))
                .route(p -> p.path("/api/fmeaEvaluate/**").uri("lb://" + RISK_ERUKA_NAME))

                // 值班
                .route(p -> p.path("/duty/**").uri("lb://" + DUTY_ERUKA_NAME))

                //匹配余下所有
                .route(p -> p.path("/api/common/**").uri("lb://" + PATROL_ERUKA_NAME))

                .build();
    }
}
